==> discordtemplate-1.1.0.tar.gz: discordtemplate-1.1.0/README.md <==
<h1 align='center'>
  Discord Template
</h1>
<p align='center'>
  🔹 A new and enhanced boilerplate template for discord.py
</p>

<p align="center">
   <a href="https://github.com/znqi">
    <img src="https://img.shields.io/github/followers/znqi?label=Follow&logo=github&style=flat-square"
         alt="GitHub">
     <a href="#License">
     <img src=https://img.shields.io/github/license/znqi/discord_template?color=5087F4&label=License&style=flat-square
          alt="License">
</p>


<p align="center">
  <a href="#about">About</a> | 
  <a href="#installation">Installation</a> | 
  <a href="#usage">Usage</a> | 
  <a href="#contributors">Contributors</a> |
  <a href="#license">License</a>
</p>

     
## About 

**Discord Template** is a Discord CLI used for creating boilerplate for bot developers out there who want to develop bots, easily and fast!
Discord Template offers you a development and deployment system (heroku) (comming soon). It's easy to use and reliable.

     
## Installation
     
Discord Template is available on [PyPi](https://pypi.org)
```
pip install discord_template
```
     
     
## Usage
```
discord create bot_name
```
![](https://cdn.discordapp.com/attachments/856819523523837972/856823350402482196/unknown.png)

## Contributors
> For contirbuting, see [CONTRIBUTING.md](https://github.com/znqi/discord_template/blob/main/CONTRIBUTING.md)

Thanks to these contributors who made the project maintained!

| ![](https://github.com/znqi.png?size=50)   |
|:-------------------------------------------:|
| [Zenqi](https://www.github.com/zenqii)     |
     
## License
[MIT]("https://github.com/znqi/discord_template/blob/main/LICENSE")

==> discordtemplate-1.1.3.tar.gz: discordtemplate-1.1.3/README.md <==
<h1 align='center'>
  Discord Template
</h1>
<p align='center'>
  🔹 A new and enhanced boilerplate template for discord.py
</p>

<p align="center">
   <a href="https://github.com/znqi">
    <img src="https://img.shields.io/github/followers/znqi?label=Follow&logo=github&style=flat-square"
         alt="GitHub">
     <a href="#License">
     <img src=https://img.shields.io/github/license/znqi/discord_template?color=5087F4&label=License&style=flat-square
          alt="License">
</p>


<p align="center">
  <a href="#about">About</a> | 
  <a href="#installation">Installation</a> | 
  <a href="#usage">Usage</a> | 
  <a href="#contributors">Contributors</a> |
  <a href="#license">License</a>
</p>

     
## About 

**Discord Template** is a Discord CLI used for creating boilerplate for bot developers out there who want to develop bots, easily and fast!
Discord Template offers you a development and deployment system (heroku) (coming soon). It's easy to use and reliable.

     
## Installation
     
Discord Template is available on [PyPi](https://pypi.org)
```
pip install discordtemplate
```
     
     
## Usage
```
discord create bot_name
```
![](https://cdn.discordapp.com/attachments/856819523523837972/856823350402482196/unknown.png)

## Contributors
> For contirbuting, see [CONTRIBUTING.md](https://github.com/znqi/discord_template/blob/main/CONTRIBUTING.md)

Thanks to these contributors who made the project maintained!

| ![](https://github.com/znqi.png?size=50)   |
|:-------------------------------------------:|
| [Zenqi](https://www.github.com/zenqii)     |
     
## License
[MIT]("https://github.com/znqi/discord_template/blob/main/LICENSE")
